@@ -12,12 +12,15 @@ from .rival300csgohyperbeastedition import rival300csgohyperbeastedition
 from .rival300dota2edition import rival300dota2edition
 from .rival300hpomen import rival300hpomen
 from .rival310 import rival310
+from .rival310pubgedition import rival310pubgedition
 from .rival500 import rival500
 from .rival600 import rival600
 from .rival700 import rival700
 from .rival710 import rival710
 from .hotssenseiraw import hotssenseiraw
 from .sensei310 import sensei310
+from .senseiraw import senseiraw
+from .senseiten import senseiten
 from .kanav2 import kanav2
 
 mice_profiles = [
@@ -35,11 +38,14 @@ mice_profiles = [
     rival300dota2edition,
     rival300hpomen,
     rival310,
+    rival310pubgedition,
     rival500,
     rival600,
     rival700,
     rival710,
     hotssenseiraw,
     sensei310,
+    senseiraw,
+    senseiten,
     kanav2,
 ]
